#
# spec file for package xyscan
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xyscan
Version:        4.30
Release:        1.1
Summary:        Data extractor from graphical plots
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://rhig.physics.yale.edu/~ullrich/software/xyscan/
Source0:        http://rhig.physics.yale.edu/~ullrich/software/xyscan/Distributions/%{version}/xyscan-%{version}-src.tgz
# PATCH-FIX-UPSTREAM no-build-date.patch -- delete build date from source
Patch0:         no-build-date.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(poppler-qt5)
Requires:       hicolor-icon-theme

%description
xyscan is a tool for scientist in the need to extract data points,
i.e. numeric values, from a plot.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
xyscan is a tool for scientist in the need to extract data points,
i.e. numeric values, from a plot.

This package contains the documentation and help files for %{name}.

%prep
%setup -q -n %{name}
%patch0 -p1

# Change hard-coded directories to proper macros
sed -i 's|/usr/local|%{_prefix}|' xyscan.pro
sed -i 's|%{_prefix}/lib|%{_libdir}|' xyscan.pro
sed -i 's|\$\$PREFIX/share/xyscan/docs|%{_docdir}/%{name}/html|' xyscan.pro
sed -i 's|\$\$PREFIX/share/xyscan/docs|%{_docdir}/%{name}/html|' src/*.cpp

# Fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' license.txt

%build
%qmake5
%make_jobs

%install
%qmake5_install

%suse_update_desktop_file -c %{name} %{name} "A visualization tool for 3D datasets" %{name} %{name} Science Math

# Install application icons
for px in 16 24 32 48 64 128 256 512 ; do
install -Dm 664 images/xyscanLogo${px}.png %{buildroot}%{_datadir}/icons/hicolor/${px}x${px}/apps/%{name}.png
done
install -Dm 664 images/xyscanIcon.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%files
%license gpl.txt license.txt
%doc README.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%exclude %{_docdir}/%{name}/html/

%files doc
%license gpl.txt license.txt
%{_docdir}/%{name}/html/

%changelog
* Tue Dec  4 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.3.0 (4.30)
  * introduces a Measure Tool. It allows one to measure distances
    in pixel, plot, and user defined units.
  * Added a warning dialog to save (or discard) data when a new
    plot is loaded and the current data is not saved.
* Sun Oct 16 2016 toddrme2178@gmail.com
- Update to version 4.1.0 (4.10)
  * The Windows version gets reintroduced in form a convenient
    binary installer.
  * For now the support of pdf files had to be dropped in the
    Window version.
  * On the Mac (and to some extent on Windows) it is now possible
    to open an image file with xyscan directly from the Finder
    (right-click then Open With). Works with the major file types
    such as png, gif, tif, jpg, and pdf.
- Update to version 4.0.0 (4.00)
  * This is a major rewrite of many parts of xyscan.
  * Changes were made to the GUI and support for PDF was added.
  * Some features that had stopped working, such as drag and drop,
    were restored.
  * The documentation was updated and simplified.
  * For certain platform-screen combinations (e.g. Retina) it is
    now possible to use even finer cursor adjustment steps than
    before (alt/option+arrow).
  * For this version, non-English language support was dropped.
- Update to version 3.3.3 (3.33)
  * This is only a maintenance release mostly for Mac OS 10.9.
  * xyscan now uses Qt 5.3. Few internal changes that were
    necessary due to the new Qtversion but nothing that affects
    the functionality.
  * For the Mac some adjustments were made to deal with Retina
    displays.
  * This version was not tested on Windows or Linux.
- Update to version 3.3.2 (3.32)
  * No upstream changelog.
- Many modifications to the .spec file to support Qt5.
- Rebase no-build-date.patch
- Change docs.patch to a sed script to support variable
  documentation installation directories.
- Use %%suse_update_desktop_file to dynamically generate .desktop
  file instead of using a separate source file.
* Sun Dec 23 2012 dmitry_r@opensuse.org
- Spec file cleanup
* Sun Sep 30 2012 dmitry_r@opensuse.org
- Fix desktop file
- Fix SLE build
* Sun Aug 12 2012 dmitry_r@opensuse.org
- fix "file contains current date" for xyscan binary
- fix documentation place
* Thu Aug  9 2012 dmitry_r@opensuse.org
- Initial package
- Version 3.3.1
